@@ -130,6 +130,13 @@ class Compiler:
                     t.Operation()
                 )
             ),
+            "contract": StdlibFunctionSpec(
+                self._compile_cast_address_to_contract,
+                lambda contract_type: FunctionPrototype(
+                    [t.Address()],
+                    t.Contract()
+                )
+            ),
             "mutez": StdlibFunctionSpec(
                 self._compile_mutez,
                 lambda: FunctionPrototype(t.Int(), t.Mutez())
@@ -146,6 +153,8 @@ class Compiler:
                 return e.types[node.id]
             elif node.id == "SENDER":
                 return t.Address()
+            elif node.id == "AMOUNT":
+                return t.Mutez()
             else:
                 if node.id == "points":
                     breakpoint()
@@ -168,8 +177,10 @@ class Compiler:
                 return t.String()
             elif type(node.value) == int:
                 return t.Int()
+            elif type(node.value) == bool:
+                return t.Bool()
             else:
-                raise E.TypeException(["str", "int"], node.value, node.lino)
+                raise E.TypeException(["str", "int", "bool"], node.value, node.lino)
         elif type(node) == ast.Subscript:
             parent_type = self.get_expression_type(node.value, e)
             if type(parent_type) == t.Dict:
@@ -529,11 +540,28 @@ class Compiler:
             Instr("PUSH", [constant_type, constant.value], {}),
         ]
 
+    def compile_unit(self, name: ast.Name, e: Env) -> List[Instr]:
+        e.sp += 1
+        return [Instr("UNIT", [], {})]
+
+    def compile_balance(self, name: ast.Name, e: Env) -> List[Instr]:
+        e.sp += 1
+        return [Instr("BALANCE", [], {})]
+
     @debug
     def compile_name(self, name: ast.Name, e: Env) -> List[Instr]:
         if name.id == "SENDER":
             return self.get_sender(name, e)
 
+        if name.id == "AMOUNT":
+            return self.get_amount(name, e)
+
+        if name.id == "unit":
+            return self.compile_unit(name, e)
+
+        if name.id == "BALANCE":
+            return self.compile_balance(name, e)
+
         var_name = name
 
         if type(name.ctx) == ast.Load:
@@ -724,6 +752,28 @@ class Compiler:
 
         return instructions
 
+    def _compile_cast_address_to_contract(self, f: ast.Call, e: Env) -> List[Instr]:
+        instructions = []
+
+        # create the contract
+        for arg in f.args:
+            instructions += self._compile(arg, e)
+
+        # cast the address to contract
+        instructions += [
+            Instr("CONTRACT", [t.Unit()], {}),
+            Instr("IF_NONE", [
+                [
+                    Instr("PUSH", [t.String(), "Contract does not exist"], {}),
+                    Instr("FAILWITH", [], {})
+                ],
+                [],
+            ], {}),
+        ]
+
+        return instructions
+
+
     def _compile_transaction(self, f: ast.Call, e: Env) -> List[Instr]:
         # fetch the operation list
         instructions = self._fetch_variable("__OPERATIONS__", e)
@@ -983,6 +1033,10 @@ class Compiler:
         e.sp += 1  # account for pushing sender
         return [Instr("SENDER", [], {})]
 
+    def get_amount(self, amount_ast: ast.Name, e: Env) -> List[Instr]:
+        e.sp += 1  # account for pushing amount
+        return [Instr("AMOUNT", [], {})]
+
 
     def _compile_attribute(self, node, e: Env) -> List[Instr]:
         instructions = []
