@@ -39,5 +39,8 @@ def compile(input_path: str, output_path: str, output_format: str = MICHELINE):
     except CompilerException as e:
         print(e.message, file=sys.stderr)
 
+
+cli = cli2.Command(compile)
+
 if __name__ == '__main__':
-    cli2.Command(compile).entry_point()
+    cli.entry_point()
