@@ -5,6 +5,12 @@ SENDER = "tz1"
 address = str
 Contract = List
 nat = int
+AMOUNT = 0
+BALANCE = 0
+
+
+def contract(a: address):
+    pass
 
 def transaction(a, b, c):
     pass
